<?php

/**
 * @param WP_Post $section
 * @return array
 */
function upage_get_section($section) {

    $result = array(
        'thumbnailUrl' => upage_get_section_thumbnail($section->ID, 'medium'),
        'id' => $section->ID,
        'status' => 2,
    );
    if (preg_match('# data-id="([^"]*?)"#', $section->post_content, $matches)) {
        $result['clientId'] = $matches[1];
    }
    return $result;
}

/**
 * @param WP_Post $post
 * @return array
 */
function upage_get_sections($post) {

    $parts = upage_split_content($post->post_content);
    $parts = array_filter($parts, create_function('$a', 'return $a["type"] === "section";'));
    $result = array();
    $order = 0;
    foreach($parts as $part) {
        $section = get_post($part['id']);
        if (!empty($section) && $section->post_type === 'upage_section') {
            $r = upage_get_section($section);
            $r['order'] = $order++;
            $r['pageId'] = $post->ID;
            $result[] = $r;
        }
    }
    return $result;
}

/**
 * @param WP_Post|int $post
 * @return array
 */
function upage_get_post($post) {
    if (is_int($post)) {
        $post = get_post($post);
    }

    $result = array(
        'siteId' => 1,
        'title' => $post->post_title,
        'publicUrl' => upage_get_editor_link(array('post_id' => $post->ID)),
        'id' => $post->ID,
        'order' => 0,
        'status' => 2,
        'items' => upage_get_sections($post),
    );
    return $result;
}

function upage_get_pages() {

    $query_options = array(
        'post_type' => 'page',
        'posts_per_page' => 10,
        'order' => 'DESC',
        'orderby' => 'modified',
        'post_status' => 'publish',
    );

    $query = new WP_Query;
    $posts = $query->query($query_options);

    $result = array();

    foreach ($posts as $post) {
        $result[] = upage_get_post($post);
    }

    return $result;
}

function upage_get_site() {

    $result = array(
        'title' => get_bloginfo('name'),
        'publicUrl' => get_home_url(),
        'id' => 1,
        'order' => 1,
        'status' => 2,
        'items' => upage_get_pages(),
    );

    return array(
        'result' => 'done',
        'data' => $result,
    );
}
upage_add_action('upage_get_site');