<?php
if (!defined('ABSPATH')) exit; // Exit if accessed directly

require_once(dirname(__FILE__) . '/post-types.php');
require_once(dirname(__FILE__) . '/admin-page.php');
require_once(dirname(__FILE__) . '/actions/actions.php');

define('UPAGE_DOMAIN', 'upage.io');

function upage_get_editor_domain() {
    $domain = isset($_REQUEST['domain'])
        ? urldecode($_REQUEST['domain'])
        : UPAGE_DOMAIN;

    $domain = preg_replace('#^https?:#', '', $domain); // remove protocol
    $domain = preg_replace('#\/$#', '', $domain); // remove last slash
    return $domain;
}

function upage_get_editor_link($args = array()) {
    $post_id = '';
    if (isset($args['post_id'])) {
        $post_id = $args['post_id'];
    } else if (isset($_GET['post'])) {
        $post_id = $_GET['post'];
    }

    if (isset($args['domain'])) {
        $domain = $args['domain'];
    } else {
        $domain = upage_get_editor_domain();
    }

    $return = add_query_arg(array('page' => 'upage_editor'), admin_url() . 'themes.php');

    if ($domain) {
        $return = add_query_arg(array('domain' => urlencode($domain)), $return);
    }
    if ($post_id) {
        $return = add_query_arg(array('p' => $post_id), $return);
    }
    return $return;
}

function upage_edit_post_link_set_domain($link) {
    $domain = upage_get_editor_domain();
    if (strpos($domain, UPAGE_DOMAIN) === false) {
        $link = add_query_arg(array('domain' => urlencode($domain)), $link);
    }
    return $link;
}
add_filter('get_edit_post_link', 'upage_edit_post_link_set_domain');

function upage_update_post_set_domain_field() {
    $domain = upage_get_editor_domain();
    if (strpos($domain, UPAGE_DOMAIN) === false) {
        printf('<input type="hidden" name="domain" value="%s" />', $domain);
    }
}
add_action('edit_form_top', 'upage_update_post_set_domain_field');

function themler_add_upage_button($post) {
    if (!isset($_REQUEST['domain']) || strpos($_REQUEST['domain'], UPAGE_DOMAIN) !== false) return; // TODO

    $type = $post->post_type;
    if ($type === 'post' || $type === 'page') {
        $editor_link = upage_get_editor_link();
?>
        <script>
            jQuery(document).on('click', '.upage-editor', function() {
                jQuery('body')
                    .prepend('<iframe src="<?php echo $editor_link; ?>" id="upage-iframe" width="100%" height="100%" frameborder="0" allowtransparency="true" style="position: fixed;z-index: 9999999;width: 100%;height: 100%;top:0;left:0;bottom: 0;"></iframe>');
            });

            function onSavingEnd(hasChanges) {
                if (hasChanges) {
                    window.location.reload();
                    return;
                }

                jQuery('#upage-iframe').remove();
            }

            function upageEventListener(event) {
                var data;
                try {
                    data = JSON.parse(event.data);
                } catch(e) {
                    console.warn(e);
                    return;
                }

                if (data.message === 'savingEnd') {
                    onSavingEnd(data.hasChanges);
                }
            }

            if (window.addEventListener) {
                window.addEventListener("message", upageEventListener);
            } else {
                window.attachEvent("onmessage", upageEventListener); // IE8
            }
        </script>
        <a href="#" id="edit-in-upage" class="button upage-editor"><?php _e('Edit in uPage', 'default'); ?></a>
<?php
    }
}
add_action('themler_edit_form_buttons', 'themler_add_upage_button');

function upage_get_section_thumbnail($section_id, $size) {
    if (!is_numeric($section_id)) {
        return '';
    }

    $post = get_post($section_id);
    if ($post->post_type !== 'upage_section') {
        return '';
    }

    $thumb_id = get_post_thumbnail_id($post->ID);
    if (!$thumb_id) {
        return '';
    }

    $image = wp_get_attachment_image_src($thumb_id, $size);
    return $image[0];
}

function upage_add_editor_page() {
    add_theme_page(__('uPage', 'default'), __('uPage', 'default'), 'edit_themes', 'upage_editor', 'upage_editor');

    // remove submenu from Appearance
    global $submenu;
    if (is_array($submenu['themes.php'])) {
        foreach($submenu['themes.php'] as $key => $value) {
            if (in_array('upage_editor', $value)) {
                unset($submenu['themes.php'][$key]);
                break;
            }
        }
    }
}
add_action('admin_menu', 'upage_add_editor_page');

function upage_editor() {
    require_once(dirname(__FILE__) . '/upage-editor.php');
    die();
}
add_action('load-appearance_page_upage_editor', 'upage_editor');